==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/container_cluster/ContainerClusterNodePoolAutoConfigOutputReference.java <==
package com.hashicorp.cdktf.providers.google.container_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:40.266Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.containerCluster.ContainerClusterNodePoolAutoConfigOutputReference")
public class ContainerClusterNodePoolAutoConfigOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected ContainerClusterNodePoolAutoConfigOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ContainerClusterNodePoolAutoConfigOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ContainerClusterNodePoolAutoConfigOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putNetworkTags(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags value) {
        software.amazon.jsii.Kernel.call(this, "putNetworkTags", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetNetworkTags() {
        software.amazon.jsii.Kernel.call(this, "resetNetworkTags", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTagsOutputReference getNetworkTags() {
        return software.amazon.jsii.Kernel.get(this, "networkTags", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTagsOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags getNetworkTagsInput() {
        return software.amazon.jsii.Kernel.get(this, "networkTagsInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfig getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfig value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/container_cluster/ContainerClusterNodePoolAutoConfigOutputReference.java <==
package com.hashicorp.cdktf.providers.google.container_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:14.210Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.containerCluster.ContainerClusterNodePoolAutoConfigOutputReference")
public class ContainerClusterNodePoolAutoConfigOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected ContainerClusterNodePoolAutoConfigOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ContainerClusterNodePoolAutoConfigOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ContainerClusterNodePoolAutoConfigOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putNetworkTags(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags value) {
        software.amazon.jsii.Kernel.call(this, "putNetworkTags", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetNetworkTags() {
        software.amazon.jsii.Kernel.call(this, "resetNetworkTags", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetResourceManagerTags() {
        software.amazon.jsii.Kernel.call(this, "resetResourceManagerTags", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTagsOutputReference getNetworkTags() {
        return software.amazon.jsii.Kernel.get(this, "networkTags", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTagsOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags getNetworkTagsInput() {
        return software.amazon.jsii.Kernel.get(this, "networkTagsInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.String> getResourceManagerTagsInput() {
        return java.util.Optional.ofNullable((java.util.Map<java.lang.String, java.lang.String>)(software.amazon.jsii.Kernel.get(this, "resourceManagerTagsInput", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))))).map(java.util.Collections::unmodifiableMap).orElse(null);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.String> getResourceManagerTags() {
        return java.util.Collections.unmodifiableMap(software.amazon.jsii.Kernel.get(this, "resourceManagerTags", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setResourceManagerTags(final @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.String> value) {
        software.amazon.jsii.Kernel.set(this, "resourceManagerTags", java.util.Objects.requireNonNull(value, "resourceManagerTags is required"));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfig getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfig.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfig value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}
